package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WmsImportResultHistoryMapper;
import com.ruoyi.system.domain.WmsImportResultHistory;
import com.ruoyi.system.service.IWmsImportResultHistoryService;

/**
 * 成品查询结果(数据同步)Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-06-20
 */
@Service
public class WmsImportResultHistoryServiceImpl implements IWmsImportResultHistoryService 
{
    @Autowired
    private WmsImportResultHistoryMapper wmsImportResultHistoryMapper;

    /**
     * 查询成品查询结果(数据同步)
     * 
     * @param id 成品查询结果(数据同步)主键
     * @return 成品查询结果(数据同步)
     */
    @Override
    public WmsImportResultHistory selectWmsImportResultHistoryById(Long id)
    {
        return wmsImportResultHistoryMapper.selectWmsImportResultHistoryById(id);
    }

    /**
     * 查询成品查询结果(数据同步)列表
     * 
     * @param wmsImportResultHistory 成品查询结果(数据同步)
     * @return 成品查询结果(数据同步)
     */
    @Override
    public List<WmsImportResultHistory> selectWmsImportResultHistoryList(WmsImportResultHistory wmsImportResultHistory)
    {
        return wmsImportResultHistoryMapper.selectWmsImportResultHistoryList(wmsImportResultHistory);
    }

    /**
     * 新增成品查询结果(数据同步)
     * 
     * @param wmsImportResultHistory 成品查询结果(数据同步)
     * @return 结果
     */
    @Override
    public int insertWmsImportResultHistory(WmsImportResultHistory wmsImportResultHistory)
    {
        return wmsImportResultHistoryMapper.insertWmsImportResultHistory(wmsImportResultHistory);
    }

    /**
     * 修改成品查询结果(数据同步)
     * 
     * @param wmsImportResultHistory 成品查询结果(数据同步)
     * @return 结果
     */
    @Override
    public int updateWmsImportResultHistory(WmsImportResultHistory wmsImportResultHistory)
    {
        wmsImportResultHistory.setUpdateTime(DateUtils.getNowDate());
        return wmsImportResultHistoryMapper.updateWmsImportResultHistory(wmsImportResultHistory);
    }

    /**
     * 批量删除成品查询结果(数据同步)
     * 
     * @param ids 需要删除的成品查询结果(数据同步)主键
     * @return 结果
     */
    @Override
    public int deleteWmsImportResultHistoryByIds(Long[] ids)
    {
        return wmsImportResultHistoryMapper.deleteWmsImportResultHistoryByIds(ids);
    }

    /**
     * 删除成品查询结果(数据同步)信息
     * 
     * @param id 成品查询结果(数据同步)主键
     * @return 结果
     */
    @Override
    public int deleteWmsImportResultHistoryById(Long id)
    {
        return wmsImportResultHistoryMapper.deleteWmsImportResultHistoryById(id);
    }
}
