package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WmsImportResultHistory;
import com.ruoyi.system.service.IWmsImportResultHistoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 成品查询结果(数据同步)Controller
 * 
 * @author ruoyi
 * @date 2025-06-20
 */
@RestController
@RequestMapping("/system/WmsImportResultHistory")
public class WmsImportResultHistoryController extends BaseController
{
    @Autowired
    private IWmsImportResultHistoryService wmsImportResultHistoryService;

    /**
     * 查询成品查询结果(数据同步)列表
     */
    @PreAuthorize("@ss.hasPermi('system:WmsImportResultHistory:list')")
    @GetMapping("/list")
    public TableDataInfo list(WmsImportResultHistory wmsImportResultHistory)
    {
        startPage();
        List<WmsImportResultHistory> list = wmsImportResultHistoryService.selectWmsImportResultHistoryList(wmsImportResultHistory);
        return getDataTable(list);
    }

    /**
     * 导出成品查询结果(数据同步)列表
     */
    @PreAuthorize("@ss.hasPermi('system:WmsImportResultHistory:export')")
    @Log(title = "成品查询结果(数据同步)", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsImportResultHistory wmsImportResultHistory)
    {
        List<WmsImportResultHistory> list = wmsImportResultHistoryService.selectWmsImportResultHistoryList(wmsImportResultHistory);
        ExcelUtil<WmsImportResultHistory> util = new ExcelUtil<WmsImportResultHistory>(WmsImportResultHistory.class);
        util.exportExcel(response, list, "成品查询结果(数据同步)数据");
    }

    /**
     * 获取成品查询结果(数据同步)详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:WmsImportResultHistory:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wmsImportResultHistoryService.selectWmsImportResultHistoryById(id));
    }

    /**
     * 新增成品查询结果(数据同步)
     */
    @PreAuthorize("@ss.hasPermi('system:WmsImportResultHistory:add')")
    @Log(title = "成品查询结果(数据同步)", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsImportResultHistory wmsImportResultHistory)
    {
        return toAjax(wmsImportResultHistoryService.insertWmsImportResultHistory(wmsImportResultHistory));
    }

    /**
     * 修改成品查询结果(数据同步)
     */
    @PreAuthorize("@ss.hasPermi('system:WmsImportResultHistory:edit')")
    @Log(title = "成品查询结果(数据同步)", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsImportResultHistory wmsImportResultHistory)
    {
        return toAjax(wmsImportResultHistoryService.updateWmsImportResultHistory(wmsImportResultHistory));
    }

    /**
     * 删除成品查询结果(数据同步)
     */
    @PreAuthorize("@ss.hasPermi('system:WmsImportResultHistory:remove')")
    @Log(title = "成品查询结果(数据同步)", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wmsImportResultHistoryService.deleteWmsImportResultHistoryByIds(ids));
    }
}
